Retrieves pathway information for a specific species and optionally filters for specific genes.
Arguments
- species_id
Numeric. The ID of the desired species (e.g., from
srch_species).- genes
A vector or column of a data frame containing gene IDs of interest. If
NULL(default), returns all pathways for the species.- category
Character. A vector or character constant of pathway categories/databases (e.g. KEGG, GOBP, GOCC, etc.). It is not recommended to use all categories, as some species have many, leading to performance issues